==> react-molecule-radio-button-field-1.12.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { jsx as _jsx } from "react/jsx-runtime";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import PropTypes from 'prop-types';
import MoleculeField from '@s-ui/react-molecule-field';
import AtomRadioButton from '@s-ui/react-atom-radio-button';
var BASE_CLASS = 'sui-MoleculeRadioButtonField';

var MoleculeRadioButtonField = function MoleculeRadioButtonField(_ref) {
  var id = _ref.id,
      label = _ref.label,
      nodeLabel = _ref.nodeLabel,
      successText = _ref.successText,
      errorText = _ref.errorText,
      alertText = _ref.alertText,
      helpText = _ref.helpText,
      onChange = _ref.onChange,
      onClickLabel = _ref.onClickLabel,
      props = _objectWithoutPropertiesLoose(_ref, ["id", "label", "nodeLabel", "successText", "errorText", "alertText", "helpText", "onChange", "onClickLabel"]);

  return /*#__PURE__*/_jsx("div", {
    className: BASE_CLASS,
    children: /*#__PURE__*/_jsx(MoleculeField, {
      name: id,
      label: label,
      nodeLabel: nodeLabel,
      successText: successText,
      errorText: errorText,
      alertText: alertText,
      helpText: helpText,
      onChange: onChange,
      onClickLabel: onClickLabel,
      inline: true,
      reverse: true,
      isAligned: true,
      children: /*#__PURE__*/_jsx(AtomRadioButton, _extends({
        id: id
      }, props))
    })
  });
};

MoleculeRadioButtonField.displayName = 'MoleculeRadioButtonField';
export default MoleculeRadioButtonField;

==> react-molecule-radio-button-field-1.13.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import PropTypes from 'prop-types';
import MoleculeField from '@s-ui/react-molecule-field';
import AtomRadioButton from '@s-ui/react-atom-radio-button';
import { jsx as _jsx } from "react/jsx-runtime";
var BASE_CLASS = 'sui-MoleculeRadioButtonField';

var MoleculeRadioButtonField = function MoleculeRadioButtonField(_ref) {
  var id = _ref.id,
      label = _ref.label,
      nodeLabel = _ref.nodeLabel,
      successText = _ref.successText,
      errorText = _ref.errorText,
      alertText = _ref.alertText,
      helpText = _ref.helpText,
      onChange = _ref.onChange,
      onClickLabel = _ref.onClickLabel,
      fullWidth = _ref.fullWidth,
      props = _objectWithoutPropertiesLoose(_ref, ["id", "label", "nodeLabel", "successText", "errorText", "alertText", "helpText", "onChange", "onClickLabel", "fullWidth"]);

  return /*#__PURE__*/_jsx("div", {
    className: BASE_CLASS,
    children: /*#__PURE__*/_jsx(MoleculeField, {
      name: id,
      label: label,
      nodeLabel: nodeLabel,
      successText: successText,
      errorText: errorText,
      alertText: alertText,
      helpText: helpText,
      onChange: onChange,
      onClickLabel: onClickLabel,
      fullWidth: fullWidth,
      inline: true,
      reverse: true,
      isAligned: true,
      children: /*#__PURE__*/_jsx(AtomRadioButton, _extends({
        id: id
      }, props))
    })
  });
};

MoleculeRadioButtonField.displayName = 'MoleculeRadioButtonField';
export default MoleculeRadioButtonField;
